@@ -57,6 +57,7 @@ void agsurv4(Sint   *ndeath,   double *risk,    double *wt,
 void agsurv5(Sint *n2,     Sint *nvar2,  Sint *dd, double *x1,  
              double *x2,   double *xsum, double *xsum2, 
              double *sum1, double *sum2, double *xbar) ;
+SEXP cdecomp(SEXP R2, SEXP time2);
 
 void chinv2  (double **matrix, int n);
 int cholesky2(double **matrix, int n, double toler);
@@ -156,7 +157,8 @@ SEXP gchol_inv(SEXP matrix, SEXP flag2);
 void init_doloop(int min, int max);
 int doloop      (int nloops, int *index);
 
-SEXP multicheck(SEXP y2, SEXP status2, SEXP id2, SEXP istate2, SEXP sort2);
+SEXP multicheck(SEXP time12,  SEXP time22, SEXP status2, SEXP id2, 
+		SEXP istate2, SEXP sort2);
 
 int *norisk(int n, double *time1, double *time2, double *status, 
 	    int *sort1, int *sort2, int *strata);
@@ -241,6 +243,7 @@ SEXP survsplit(SEXP tstart2,  SEXP tstop2,  SEXP cut2);
 SEXP tmerge (SEXP id2,  SEXP time2x, SEXP newx2,
 	     SEXP nid2, SEXP ntime2, SEXP x2,  SEXP indx2); 
 SEXP tmerge2(SEXP id2,  SEXP time2x, SEXP nid2, SEXP ntime2);
+SEXP tmerge3(SEXP id2, SEXP miss2);
 
 SEXP zph1(SEXP gt2,    SEXP y2, 
 	  SEXP covar2, SEXP eta2,  SEXP weights2,
